EXPORTS
	??0RMetaDataContainerBase@Meta@@QAE@XZ @ 1 NONAME ; public: __thiscall Meta::RMetaDataContainerBase::RMetaDataContainerBase(void)
	??0SMetaData@Meta@@IAE@XZ @ 2 NONAME ; protected: __thiscall Meta::SMetaData::SMetaData(void)
	??0SMetaDataECom@Meta@@IAE@XZ @ 3 NONAME ; protected: __thiscall Meta::SMetaDataECom::SMetaDataECom(void)
	??1SMetaData@Meta@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall Meta::SMetaData::~SMetaData(void)
	??1SMetaDataECom@Meta@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall Meta::SMetaDataECom::~SMetaDataECom(void)
	?Copy@RMetaDataContainerBase@Meta@@QAEXABV12@@Z @ 6 NONAME ; public: void __thiscall Meta::RMetaDataContainerBase::Copy(class Meta::RMetaDataContainerBase const &)
	?Copy@SMetaData@Meta@@QAEXABU12@@Z @ 7 NONAME ; public: void __thiscall Meta::SMetaData::Copy(struct Meta::SMetaData const &)
	?Length@RMetaDataContainerBase@Meta@@QBEHXZ @ 8 NONAME ; public: int __thiscall Meta::RMetaDataContainerBase::Length(void)const 
	?Length@SMetaData@Meta@@QBEHXZ @ 9 NONAME ; public: int __thiscall Meta::SMetaData::Length(void)const 
	?Load@RMetaDataContainerBase@Meta@@QAEHAAVTPtrC8@@@Z @ 10 NONAME ; public: int __thiscall Meta::RMetaDataContainerBase::Load(class TPtrC8 &)
	?Load@SMetaData@Meta@@QAEHAAVTPtrC8@@@Z @ 11 NONAME ; public: int __thiscall Meta::SMetaData::Load(class TPtrC8 &)
	?LoadL@SMetaDataECom@Meta@@SAPAU12@AAVTPtrC8@@@Z @ 12 NONAME ; public: static struct Meta::SMetaDataECom * __cdecl Meta::SMetaDataECom::LoadL(class TPtrC8 &)
	?NewInstanceL@SMetaDataECom@Meta@@SAPAU12@ABUSTypeId@2@@Z @ 13 NONAME ; public: static struct Meta::SMetaDataECom * __cdecl Meta::SMetaDataECom::NewInstanceL(struct Meta::STypeId const &)
	?Store@RMetaDataContainerBase@Meta@@QBEHAAVTDes8@@@Z @ 14 NONAME ; public: int __thiscall Meta::RMetaDataContainerBase::Store(class TDes8 &)const 
	?Store@SMetaData@Meta@@QBEHAAVTDes8@@@Z @ 15 NONAME ; public: int __thiscall Meta::SMetaData::Store(class TDes8 &)const 
	?GetTypeId@SMetaData@Meta@@QBE?AUSTypeId@2@XZ @ 16 NONAME ; public: struct Meta::STypeId  __thiscall Meta::SMetaData::GetTypeId(void)const 
	?IsTypeOf@SMetaData@Meta@@QBEHABUSTypeId@2@@Z @ 17 NONAME ; public: int __thiscall Meta::SMetaData::IsTypeOf(struct Meta::STypeId const &)const 
	??0TMetaVTableIterator@Meta@@QAE@PBVMMetaData@1@@Z @ 18 NONAME ; Meta::TMetaVTableIterator::TMetaVTableIterator(class Meta::MMetaData const *)
	??ETMetaVTableIterator@Meta@@QAEPBUSVDataTableEntry@1@H@Z @ 19 NONAME ; struct Meta::SVDataTableEntry const * Meta::TMetaVTableIterator::operator++(int)
	?Check@STypeId@Meta@@QBEHAAVTPtrC8@@@Z @ 20 NONAME ; int Meta::STypeId::Check(class TPtrC8 &) const
	?CheckTypeOf@SMetaData@Meta@@QBEHAAVTPtrC8@@@Z @ 21 NONAME ; int Meta::SMetaData::CheckTypeOf(class TPtrC8 &) const
	?Copy@TMetaBuf16@Meta@@UAEXPBX@Z @ 22 NONAME ; void Meta::TMetaBuf16::Copy(void const *)
	?Copy@TMetaBuf8@Meta@@UAEXPBX@Z @ 23 NONAME ; void Meta::TMetaBuf8::Copy(void const *)
	?Length@TMetaBuf16@Meta@@UBEHXZ @ 24 NONAME ; int Meta::TMetaBuf16::Length(void) const
	?Length@TMetaBuf8@Meta@@UBEHXZ @ 25 NONAME ; int Meta::TMetaBuf8::Length(void) const
	?Load@TMetaArrayBase@Meta@@UAEHAAVTPtrC8@@@Z @ 26 NONAME ; int Meta::TMetaArrayBase::Load(class TPtrC8 &)
	?Load@TMetaBuf16@Meta@@UAEHAAVTPtrC8@@@Z @ 27 NONAME ; int Meta::TMetaBuf16::Load(class TPtrC8 &)
	?Load@TMetaBuf8@Meta@@UAEHAAVTPtrC8@@@Z @ 28 NONAME ; int Meta::TMetaBuf8::Load(class TPtrC8 &)
	?Load@TMetaVarLenBase@Meta@@UAEHAAVTPtrC8@@@Z @ 29 NONAME ; int Meta::TMetaVarLenBase::Load(class TPtrC8 &)
	?Store@TMetaArrayBase@Meta@@UBEHAAVTDes8@@@Z @ 30 NONAME ; int Meta::TMetaArrayBase::Store(class TDes8 &) const
	?Store@TMetaBuf16@Meta@@UBEHAAVTDes8@@@Z @ 31 NONAME ; int Meta::TMetaBuf16::Store(class TDes8 &) const
	?Store@TMetaBuf8@Meta@@UBEHAAVTDes8@@@Z @ 32 NONAME ; int Meta::TMetaBuf8::Store(class TDes8 &) const
	?Store@TMetaVarLenBase@Meta@@UBEHAAVTDes8@@@Z @ 33 NONAME ; int Meta::TMetaVarLenBase::Store(class TDes8 &) const
	?GetTypeId@RMetaDataContainerBase@Meta@@QBE?AUSTypeId@2@XZ @ 34 NONAME ; struct Meta::STypeId Meta::RMetaDataContainerBase::GetTypeId(void) const
	??1TMetaVTableIterator@Meta@@QAE@XZ @ 35 NONAME ; Meta::TMetaVTableIterator::~TMetaVTableIterator(void)
	??0CMetaDataVirtualCtorBase@Meta@@QAE@XZ @ 36 NONAME ABSENT ; Meta::CMetaDataVirtualCtorBase::CMetaDataVirtualCtorBase(void)
	??0STypeId@Meta@@QAE@AAVTPtrC8@@@Z @ 37 NONAME ABSENT ; Meta::STypeId::STypeId(class TPtrC8 &)
	??1CMetaDataVirtualCtorBase@Meta@@UAE@XZ @ 38 NONAME ABSENT ; Meta::CMetaDataVirtualCtorBase::~CMetaDataVirtualCtorBase(void)
	??2SMetaDataNetCtor@Meta@@SAPAXIAAVTDes8@@@Z @ 39 NONAME ; void * Meta::SMetaDataNetCtor::operator new(unsigned int, class TDes8 &)
	?DeregisterInterface@CMetaDataVirtualCtorBase@Meta@@QAEXVTUid@@@Z @ 40 NONAME ABSENT ; void Meta::CMetaDataVirtualCtorBase::DeregisterInterface(class TUid)
	?FindRawCtor@CMetaDataVirtualCtorBase@Meta@@IBEPAXABUSTypeId@2@@Z @ 41 NONAME ABSENT ; void * Meta::CMetaDataVirtualCtorBase::FindRawCtor(struct Meta::STypeId const &) const
	?New@CMetaDataVirtualCtorInPlace@Meta@@QBEPAVSMetaDataNetCtor@2@ABUSTypeId@2@AAVTPtrC8@@AAVTDes8@@@Z @ 42 NONAME ; class Meta::SMetaDataNetCtor * Meta::CMetaDataVirtualCtorInPlace::New(struct Meta::STypeId const &, class TPtrC8 &, class TDes8 &) const
	?RegisterInterfaceL@CMetaDataVirtualCtorBase@Meta@@QAEXVTUid@@HPBUTImplementationProxy@@@Z @ 43 NONAME ABSENT ; void Meta::CMetaDataVirtualCtorBase::RegisterInterfaceL(class TUid, int, struct TImplementationProxy const *)
	?Copy@TMetaVarLenBase@Meta@@UAEXPBX@Z @ 44 NONAME ; void Meta::TMetaVarLenBase::Copy(void const *)
	?IsInterfaceRegistered@CMetaDataVirtualCtorBase@Meta@@QBEHVTUid@@@Z @ 45 NONAME ABSENT ; int Meta::CMetaDataVirtualCtorBase::IsInterfaceRegistered(class TUid) const
	?Length@TMetaVarLenBase@Meta@@UBEHXZ @ 46 NONAME ; int Meta::TMetaVarLenBase::Length(void) const
	?New@CMetaDataVirtualCtorInPlace@Meta@@QBEPAVSMetaDataNetCtor@2@AAVTPtrC8@@AAVTDes8@@@Z @ 47 NONAME ; class Meta::SMetaDataNetCtor * Meta::CMetaDataVirtualCtorInPlace::New(class TPtrC8 &, class TDes8 &) const
	?New@CMetaDataVirtualCtorInPlace@Meta@@QBEPAVSMetaDataNetCtor@2@ABUSTypeId@2@AAVTDes8@@@Z @ 48 NONAME ; class Meta::SMetaDataNetCtor * Meta::CMetaDataVirtualCtorInPlace::New(struct Meta::STypeId const &, class TDes8 &) const
	?NewL@TMetaBuf16@Meta@@SAPAVMMetaType@2@PBX0@Z @ 49 NONAME ; class Meta::MMetaType * Meta::TMetaBuf16::NewL(void const *, void const *)
	?NewL@TMetaBuf8@Meta@@SAPAVMMetaType@2@PBX0@Z @ 50 NONAME ; class Meta::MMetaType * Meta::TMetaBuf8::NewL(void const *, void const *)
	?Check@SMetaData@Meta@@QBEHAAVTPtrC8@@@Z @ 51 NONAME ; int Meta::SMetaData::Check(class TPtrC8 &) const
	?CreateSTypeId@STypeId@Meta@@SA?AU12@AAVTPtrC8@@@Z @ 52 NONAME ; struct Meta::STypeId Meta::STypeId::CreateSTypeId(class TPtrC8 &)

